package App::RunStopRun;

use strict;
use warnings;

our $VERSION = '0.04';
$VERSION = eval $VERSION;

1;

__END__

=head1 NAME

App::RunStopRun - limit CPU usage of processes

=head1 DESCRIPTION

This is a stub module, see F<bin/run-stop-run> for complete documentation.

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2022 gray <gray at cpan.org>

This program is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
